Documentation
¶
Index ¶
- type Util
- func (_ *Util) DrawColourBars(gc *draw2dimg.GraphicContext, bounds util.Rectangle, cols ...color.Color) (float64, float64)
- func (_ *Util) DrawColourBarsVertical(gc *draw2dimg.GraphicContext, bounds util.Rectangle, cols ...color.Color) (float64, float64)
- func (_ *Util) DrawStringCenter(gc *draw2dimg.GraphicContext, x, y float64, s string, a ...interface{}) float64
- func (_ *Util) DrawStringLeft(gc *draw2dimg.GraphicContext, x, y float64, s string, a ...interface{}) float64
- func (_ *Util) DrawStringRight(gc *draw2dimg.GraphicContext, x, y float64, s string, a ...interface{}) float64
- func (_ *Util) FitString(l, t, r, b, sl, st, sr, sb float64) (float64, float64, float64, float64)
- func (_ *Util) FloatToA(v float64) string
- func (_ *Util) GetImageFiles(dir string) ([]string, error)
- func (_ *Util) GetStringBounds(gc *draw2dimg.GraphicContext, s string) util.Rectangle
- func (_ *Util) NewGraphicContext(img draw.Image) *draw2dimg.GraphicContext
- func (_ *Util) ParseTime(s string) time.Time
- func (_ *Util) ParseTimeIn(s string, loc *time.Location) time.Time
- func (_ *Util) Rect(x1, y1, x2, y2 float64) util.Rectangle
- func (_ *Util) Sequence(interval int, sourceFiles []string) *frames.FrameSet
- func (_ *Util) SequenceIn(interval int, sourceFiles []string, loc *time.Location) *frames.FrameSet
- func (_ *Util) StringSize(gc *draw2dimg.GraphicContext, s string, a ...interface{}) util.Rectangle
- func (_ *Util) TimeFromFileName(s string) time.Time
- func (_ *Util) TimeFromFileNameIn(s string, loc *time.Location) time.Time
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Util ¶
type Util struct {
}
func (*Util) DrawColourBars ¶
func (*Util) DrawColourBarsVertical ¶
func (*Util) DrawStringCenter ¶
func (*Util) DrawStringLeft ¶
func (*Util) DrawStringRight ¶
func (*Util) GetImageFiles ¶
GetImageFiles returns a list of image files from a directory. The results will be images which are supported and who's names are timestamps. The result will be sorted in the correct order.
func (*Util) GetStringBounds ¶
func (*Util) NewGraphicContext ¶
func (_ *Util) NewGraphicContext(img draw.Image) *draw2dimg.GraphicContext
func (*Util) SequenceIn ¶
func (*Util) StringSize ¶
Click to show internal directories.
Click to hide internal directories.